==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-customcommand/translations/customcommand_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="176"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Configuração de Comando Personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Exibição</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Use icon from theme or browse file</source>
        <translation>Usar o ícone do tema ou buscar arquivo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Execute com &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
        <source>Select Font</source>
        <translation>Selecionar Fonte</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Use %1 to display command output</source>
        <translation>Use %1 para mostrar a saída do comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Girar automaticamente quando o painel estiver vertical</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
        <source>echo Configure...</source>
        <translation>echo Configurar...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <source>Command to run</source>
        <translation>Comando para executar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
        <source>Max Width</source>
        <translation>Largura máxima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
        <source>Repeat command after:</source>
        <translation>Repitir o comando após:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source> second(s)</source>
        <translation> segundo(s)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
        <source>Mouse Commands</source>
        <translation>Comandos do mouse</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
        <source>Click</source>
        <translation>Clique</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Wheel Up</source>
        <translation>Roda para cima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
        <source>Wheel Down</source>
        <translation>Roda para baixo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Select Icon File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.3.0.tar.xz: lxqt-panel-1.3.0/plugin-customcommand/translations/customcommand_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="176"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Configuração de Comando Personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Exibição</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Use icon from theme or browse file</source>
        <translation>Usar o ícone do tema ou buscar arquivo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Execute com &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
        <source>Select Font</source>
        <translation>Selecionar Fonte</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Use %1 to display command output</source>
        <translation>Use %1 para mostrar a saída do comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Girar automaticamente quando o painel estiver vertical</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
        <source>echo Configure...</source>
        <translation>echo Configurar...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <source>Command to run</source>
        <translation>Comando para executar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
        <source>Max Width</source>
        <translation>Largura máxima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
        <source>Repeat command after:</source>
        <translation>Repitir o comando após:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source> second(s)</source>
        <translation> segundo(s)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
        <source>Mouse Commands</source>
        <translation>Comandos do mouse</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
        <source>Click</source>
        <translation>Clique</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Wheel Up</source>
        <translation>Roda para cima</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
        <source>Wheel Down</source>
        <translation>Roda para baixo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Select Icon File</source>
        <translation>Selecionar arquivo de ícone</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Imagens (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
